|pypi| |actions| |coverage|

edc-lab-dashboard
-----------------

Lab dashboard views for clinic/edc projects


.. |pypi| image:: https://img.shields.io/pypi/v/edc-lab-dashboard.svg
    :target: https://pypi.python.org/pypi/edc-lab-dashboard

.. |actions| image:: https://github.com/clinicedc/edc-lab-dashboard/actions/workflows/build.yml/badge.svg
  :target: https://github.com/clinicedc/edc-lab-dashboard/actions/workflows/build.yml

.. |coverage| image:: https://coveralls.io/repos/github/clinicedc/edc-lab-dashboard/badge.svg?branch=develop
    :target: https://coveralls.io/github/clinicedc/edc-lab-dashboard?branch=develop
